import * as Konva from "konva";
import * as ROSLib from "roslib";
interface IR2d {
    container: HTMLElement;
    zoom: boolean;
    pan: boolean;
    scale: number;
    ros: IRosBridgeURL | IRos;
}
interface IMap {
    image: HTMLImageElement;
    info: {
        origin: number[];
        resolution: number;
    };
}
interface IPose {
    object: Konva.Circle | Konva.Rect | Konva.Arrow | Konva.Image;
    topic: string;
    queueLength?: number;
    throttleRate?: number;
}
export interface IRosBridgeURL {
    url: string;
}
export declare type IRos = ROSLib.Ros;
interface IStaticObject {
    object: Konva.Circle | Konva.Rect | Konva.Arrow | Konva.Image;
    x: number;
    y: number;
    rotationInDegClockwise?: number;
}
interface IPath {
    points: Array<{
        x: number;
        y: number;
    }>;
    color: string;
    width: number;
    tension?: number;
}
export default class R2d {
    private readonly container;
    private readonly stage;
    private readonly zoom;
    private readonly pan;
    private readonly scale;
    private readonly ros;
    private readonly mapLayer;
    private readonly objectsLayer;
    static createMap: (args: import("./helpers/map").IMap) => Promise<import("./helpers/map").IMapReturnSuccess>;
    static createCircle: (args: import("./helpers/circle").ICircle) => Konva.Circle;
    static createRectangle: (args: import("./helpers/rectangle").IRectangle) => Konva.Rect;
    static createArrow: (args: import("./helpers/arrow").IArrow) => Konva.Arrow;
    static createImageSync: (args: import("./helpers/image").IImageSync) => Konva.Image;
    static createImageAsync: (args: import("./helpers/image").IImageAsync) => Promise<import("./helpers/image").IImageAsyncReturnSuccess>;
    constructor(args: IR2d);
    addMap: (map: IMap) => {
        destroy: () => void;
    };
    addPose: (pose: IPose) => {
        destroy: () => void;
    };
    addStaticObject: (args: IStaticObject) => {
        destroy: () => void;
    };
    addPath: (args: IPath) => {
        destroy: () => void;
    };
}
export {};
