import { isNil } from "lodash";
import * as Konva from "konva";

interface IImage {
  width?: number;
  height?: number;
  border?: number;
  borderColor?: string;
  opacity?: number;
}

export type IImageSync = IImage & { image: HTMLImageElement };
export type IImageAsync = IImage & { imageURL: string };

export interface IImageAsyncReturnSuccess {
  image: Konva.Image;
}

export const imageSync = (args: IImageSync) =>
  new Konva.Image({
    image: args.image,
    width: !isNil(args.width)
      ? args.width
      : !isNil(args.height)
        ? (args.image.naturalWidth / args.image.naturalHeight) * args.height
        : args.image.naturalWidth,
    height: !isNil(args.height)
      ? args.height
      : !isNil(args.width)
        ? (args.image.naturalHeight / args.image.naturalWidth) * args.width
        : args.image.naturalHeight,
    offsetY:
      (!isNil(args.height)
        ? args.height
        : !isNil(args.width)
          ? (args.image.naturalHeight / args.image.naturalWidth) * args.width
          : args.image.naturalHeight) / 2,
    strokeEnabled: isNil(args.border) ? false : args.border !== 0,
    strokeWidth: !isNil(args.border) ? args.border : 0,
    stroke: !isNil(args.borderColor) ? args.borderColor : "black",
    opacity: !isNil(args.opacity) ? args.opacity : 1
  });

export const imageAsync = async (args: IImageAsync) => {
  const image = new Image();
  image.src = args.imageURL;
  return new Promise<IImageAsyncReturnSuccess>(resolve => {
    image.onload = () =>
      resolve({
        image: new Konva.Image({
          image,
          width: !isNil(args.width)
            ? args.width
            : !isNil(args.height)
              ? (image.naturalWidth / image.naturalHeight) * args.height
              : image.naturalWidth,
          height: !isNil(args.height)
            ? args.height
            : !isNil(args.width)
              ? (image.naturalHeight / image.naturalWidth) * args.width
              : image.naturalHeight,
          offsetY:
            (!isNil(args.height)
              ? args.height
              : !isNil(args.width)
                ? (image.naturalHeight / image.naturalWidth) * args.width
                : image.naturalHeight) / 2,
          strokeEnabled: isNil(args.border) ? false : args.border !== 0,
          strokeWidth: !isNil(args.border) ? args.border : 0,
          stroke: !isNil(args.borderColor) ? args.borderColor : "black",
          opacity: !isNil(args.opacity) ? args.opacity : 1
        })
      });
    image.onerror = () => {
      throw new Error("error loading image");
    };
  });
};
